Documentation
¶
Overview ¶
Package jsonstruct describe how data is serialized to json in communication between gpuserver and gpuserver-ds .
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type NodeGpuInfo ¶
type NodeGpuInfo struct {
NodeName string `json:"device_node,omitempty"`
GpuInfos map[string]*GpuInfo `json:"device_infos,omitempty"`
Models map[string]sets.String `json:"device_models,omitempty"`
// Used in gpuserver to record the time message received by the gpuserver
ReportTime time.Time `json:"report_time,omitempty"`
}
type PodResourceUpdate ¶
type PodResourceUpdate struct {
PodResourcesSYNC []*PodResourcesDetail //we don't have to tell the add and update
PodResourcesDEL []*podresourcesapi.PodResources
NodeName string
}
type PodResourcesDetail ¶
type PodResourcesDetail struct {
*podresourcesapi.PodResources
ContainerDevices *[]*ContainerResourcesDetail `json:"containers_device,omitempty"`
}
Click to show internal directories.
Click to hide internal directories.